import components from './components'

function normalize (item) {
  return item ? String(item).replace(/\s+/g, ' ').trim() : null
}

function normalizePhone (item) {
  let phone = String(item).replace(/\s|\+|\(|\)|\/|,|-|'/g, '').replace(/^0+/, '')
  if (phone.match(/[^\d*]/)) {
    return `FEHLER: ${phone}`
  }
  if (phone.length === 9) {
    // Missing 0
    phone = `0${phone}`
  }

  const len = phone.length
  if (phone[len - 10] === '0') {
    return `${phone.substring(len - 10, len - 7)} ${phone.substring(len - 7, len - 4)} ${phone.substring(len - 4, len - 2)} ${phone.substring(len - 2, len)}`
  }
  if (len > 10) {
    return `FEHLER: ${phone} ${phone.substring(0, len - 7)}`
  }
  return `${phone}`
}

const state = {
  players: [],
  filtered: [],
  categories: [],
  filters: {}
}

/** Class representing a player */
class Player {
  /**
   * Create a player
   * A player data item in the Swisstennis PlayerList.xlsx file has the following columns
   * Konkurrenz | Anmeldedatum | Lizenznummer | Klub | Klub Name | Name | Vorname | Geburtsdatum | Adresse | c/o | PLZ | Ort |
   * Land | Tel P | Tel G | Mobile | Email | Klassierung | Klass. Wert | Gesetzte | Kommentar | Einschränkungen | Kommentar |
   * Lizenz Nr.Doppelpartner | Name Doppelpartner | Vorname Doppelpartner | Geburtsdatum Doppelpartner | Klassierung Doppelpartner |
   * Klass. Wert Doppelpartner | bestätigt | On-line Anmeldung | bezahlt
   */
  constructor (data) {
    this.Konkurrenz = normalize(data[0])
    this.Lizenz = normalize(data[2])
    this.Name = normalize(data[5])
    this.Vorname = normalize(data[6])
    this.Geburtsdatum = data[7]
    this.TelP = normalizePhone(data[13])
    this.TelG = normalizePhone(data[14])
    this.Mobile = normalizePhone(data[15])
    this.Klassierung = normalize(data[17])
    this.LizenzDP = normalize(data[23])
    this.NameDP = normalize(data[24])
    this.VornameDP = normalize(data[25])
    this.GeburtsdatumDP = data[26]
    this.KlassierungDP = normalize(data[27])
    this.Bestaetigt = data[29]
    this.Bezahlt = data[31]
    this.BezahltAm = null
    this.Matches = []
    this.isDoubles = this.Konkurrenz.match(/DM.*|[MW]D.*/)
    this.isJunior = (this.Geburtsdatum) ? this.Geburtsdatum.getTime() >= (new Date((new Date()).getFullYear() - 18, 11, 31, 23, 59, 59, 999)).getTime() : false
    this.isJuniorDP = (this.isDoubles & !!this.GeburtsdatumDP) ? this.GeburtsdatumDP.getTime() >= (new Date((new Date()).getFullYear() - 18, 11, 31, 23, 59, 59, 999)).getTime() : false
    this.name = this.isDoubles ? `${this.Name} ${this.Vorname} / ${this.NameDP} ${this.VornameDP}` : `${this.Name} ${this.Vorname}`
  }
}

export default { Player, components, state }
